Records — BCI-Framework documentation

# Records

class `bci_framework.framework.widgets.records.` `Records`(parent, core)

  Widget with rocords and offline streaming.

  `connect`() → None

    Connect events.

  `get_metadata`(filename: str, light: bool = True) → None

    Read the record file and load the header.

  `get_offset`() → float

    The offset for slider animation.

  `load_file`(item) → None

    Prepare file to stream it in offline mode.

  `load_records`() → None

    Load all records from records directory.

  `on_focus`() → None

    Reload records.

  `record_renamed`(item) → None

    Rename records file.

  `record_signal`(toggled: bool) → None

    Start record and start record animation.

  `remove_record`() → None

    Remove file from records directory.

  `stream_record`(toggled) → None

    Start the stream.

  `update_record_time`() → None

    Update the value of the current streamed signal.

  `update_timer`() → None

    Stream data into kafka.

  `update_timer_record`() → None

    Update the timer to indicate that the records is active.